summaryrefslogtreecommitdiffstats
path: root/win/nmakehlp.c
diff options
context:
space:
mode:
Diffstat (limited to 'win/nmakehlp.c')
-rw-r--r--win/nmakehlp.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/win/nmakehlp.c b/win/nmakehlp.c
index d0edcf0..b1a1517 100644
--- a/win/nmakehlp.c
+++ b/win/nmakehlp.c
@@ -498,9 +498,10 @@ GetVersionFromFile(
p = strstr(szBuffer, match);
if (p != NULL) {
/*
* Skip to first digit.
*/
+ p += strlen(match);
while (*p && !isdigit(*p)) {
++p;
}
@@ -630,11 +631,11 @@ SubstituteFile(
}
}
#endif
-
+
/*
* Run the substitutions over each line of the input
*/
-
+
while (fgets(szBuffer, cbBuffer, fp) != NULL) {
list_item_t *p = NULL;
for (p = substPtr; p != NULL; p = p->nextPtr) {
@@ -654,7 +655,7 @@ SubstituteFile(
}
printf(szBuffer);
}
-
+
list_free(&substPtr);
}
fclose(fp);
@@ -498,9 +498,10 @@ GetVersionFromFile(
if (p != NULL) {
/*
- * Skip to first digit.
+ * Skip to first digit after the match.
*/